FrStorageEntry_ class

FrStorageEntry entity fields to define ObjectBox queries.

Constructors

FrStorageEntry_()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

id QueryIntegerProperty<FrStorageEntry>
See FrStorageEntry.id.
final
keyHash QueryStringProperty<FrStorageEntry>
See FrStorageEntry.keyHash.
final
payload QueryStringProperty<FrStorageEntry>
See FrStorageEntry.payload.
final
scopeHash QueryStringProperty<FrStorageEntry>
See FrStorageEntry.scopeHash.
final